@@ -1,51 +1,26 @@
-/* *
- *    OPEN-XCHANGE legal information
+/*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    All intellctual property rights in the Software are protected by
- *    international copyright laws.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
+
+
 package com.openexchange.documentconverter.client.impl;
 
 import static org.apache.commons.lang.StringUtils.isBlank;
@@ -84,7 +59,8 @@ public class ClientConfig {
     final private static String CONFIGITEM_ENABLE_CACHE_LOOKUP = "com.openexchange.documentconverter.enableCacheLookup";
     final private static String CONFIGITEM_SUPPORTED_TYPES = "com.openexchange.documentconverter.client.supportedTypes";
     final private static String CONFIGITEM_PDFEXTRACTOR_INSTALL_DIR = "com.openexchange.documentconverter.client.pdfextractor.installDir";
-    final private static String CONFIGITEM_PDFEXTRACTOR_WORK_DIR ="com.openexchange.documentconverter.client.pdfextractor.workDir";
+    final private static String CONFIGITEM_PDFEXTRACTOR_WORK_DIR = "com.openexchange.documentconverter.client.pdfextractor.workDir";
+    final private static String CONFIGITEM_PDFEXTRACTOR_MAX_VMEM_MB = "com.openexchange.documentconverter.client.pdfextractor.maxVMemMB";
     final private static String CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS = "com.openexchange.documentconverter.client.autoCleanupTimeoutSeconds";
 
 
@@ -98,6 +74,7 @@ public class ClientConfig {
         CONFIGITEM_SUPPORTED_TYPES,
         CONFIGITEM_PDFEXTRACTOR_INSTALL_DIR,
         CONFIGITEM_PDFEXTRACTOR_WORK_DIR,
+        CONFIGITEM_PDFEXTRACTOR_MAX_VMEM_MB,
         CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS
     };
 
@@ -170,6 +147,13 @@ public class ClientConfig {
      * extraction executable working directory.
      */
     public File PDFEXTRACTOR_WORKDIR = new File("/tmp", PDFEXTRACTOR_EXECUTABLE_WORKDIR_NAME);
+    
+    /**
+     * The maximum virtual memory in MegaBytes that an externally
+     * started PDF extractor process is allowed to allocate
+     */
+    public int PDFEXTRACTOR_MAX_VMEM_MB = 1024;
+
 
     /**
      * The path to the directory, containing the PDF
@@ -303,6 +287,13 @@ public class ClientConfig {
             }
         }
 
+        // CONFIGITEM_PDFEXTRACTOR_MAX_VMEM_MB
+        if (itemsToRead.contains(CONFIGITEM_PDFEXTRACTOR_MAX_VMEM_MB) &&
+            (curIntEntry = configService.getIntProperty(CONFIGITEM_PDFEXTRACTOR_MAX_VMEM_MB, emptyInt)) != emptyInt) {
+
+            PDFEXTRACTOR_MAX_VMEM_MB = Math.max(curIntEntry, -1);
+        }
+
         // CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS
         if (itemsToRead.contains(CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS) &&
             (curIntEntry = configService.getIntProperty(CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS, emptyInt)) != emptyInt) {
