@@ -1,52 +1,27 @@
-/* *
- *    OPEN-XCHANGE legal information
+/*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    All intellctual property rights in the Software are protected by
- *    international copyright laws.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 
+
+
 package com.openexchange.documentconverter.client.json;
 
 import java.io.File;
@@ -60,6 +35,7 @@ import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.documentconverter.DocumentConverterManager;
+import com.openexchange.documentconverter.FileAndURL;
 import com.openexchange.documentconverter.FileIdManager;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
@@ -156,9 +132,9 @@ class ConvertDocumentAction extends DocumentConverterAction {
         @NonNull MutableWrapper<JobError> jobError) {
 
         final MutableWrapper<String> jobId = new MutableWrapper<>(UUID.randomUUID().toString());
-        final File pdfResultFile = getPDFFile(request, session, false, documentDecrypted, jobId, jobError);
+        final FileAndURL pdfResultFileAndURL = getPDFFileAndURL(request, session, false, documentDecrypted, jobId, jobError);
 
-        if (null != pdfResultFile) {
+        if ((null != pdfResultFileAndURL) && (null != pdfResultFileAndURL.getFile())) {
             try {
                 // resource is held with a configured timeout of AUTO_CLEANUP_TIMEOUT_MILLIS
                 m_fileIdManager.lock(jobId.get(), m_clientConfig.AUTO_CLEANUP_TIMEOUT_MILLIS);
@@ -166,7 +142,8 @@ class ConvertDocumentAction extends DocumentConverterAction {
                 final PDFExtractor pdfExtractor = m_manager.getPDFExtractor();
 
                 if (null != pdfExtractor) {
-                    final int pageCount = pdfExtractor.getPageCount(pdfResultFile);
+                    final String fileName = request.getParameter("filename");
+                    final int pageCount = pdfExtractor.getPageCount(pdfResultFileAndURL.getFile(), fileName);
 
                     if (pageCount > 0) {
                         jsonResult.put("jobID", jobId.get());
@@ -214,30 +191,33 @@ class ConvertDocumentAction extends DocumentConverterAction {
                 m_fileIdManager.lock(jobId);
 
                 final PDFExtractor pdfExtractor = m_manager.getPDFExtractor();
-                final File pdfInputFile = m_fileIdManager.getDataFile(jobId);
+                final FileAndURL pdfInputFileAndURL = m_fileIdManager.getDataFileAndURL(jobId);
 
-                if (null == pdfInputFile) {
+                if ((null == pdfInputFileAndURL) || (null == pdfInputFileAndURL.getFile())) {
                     DocumentConverterManager.logError("DC client Ajax #getPage handler got no input file for PDF document. The input file has been removed by auto cleanup handler in the meantime: " + jobId);
                     jobError.set(JobError.NO_CONTENT);
                 } else if (null == pdfExtractor) {
                     DocumentConverterManager.logError("DC client Ajax #getPage handler has no valid PDFExtractor to get page from PDF file : " + jobId);
                     jobError.set(JobError.GENERAL);
                 } else {
+                    final String fileName = request.getParameter("filename");
                     final String targetWidthStr = request.getParameter("target_width");
                     final String targetHeightStr = request.getParameter("target_height");
                     final int pixelWidth = new Integer((null != targetWidthStr) ? targetWidthStr : "-1").intValue();
                     final int pixelHeight = new Integer((null != targetHeightStr) ? targetHeightStr : "-1").intValue();
 
+
                     tmpOutputFile = m_manager.createTempFile(jobId);
 
-                    m_manager.getPDFExtractor().extractToGraphic(
-                        pdfInputFile,
+                    pdfExtractor.extractToGraphic(
+                        pdfInputFileAndURL.getFile(),
                         tmpOutputFile,
                         targetFormat,
                         pageNumber,
                         pixelWidth,
                         pixelHeight,
-                        "contain");
+                        "contain",
+                        fileName);
 
                     // prepare Ajax result object
                     resultFileHolder = new FileHolder(
