@@ -1,54 +1,28 @@
-/* *
- *    OPEN-XCHANGE legal information
+/*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    All intellctual property rights in the Software are protected by
- *    international copyright laws.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
+
+
 package com.openexchange.documentconverter.client.json;
 
-import java.io.File;
 import java.io.InputStream;
 import java.util.EnumSet;
 import java.util.HashMap;
@@ -64,27 +38,37 @@ import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
 import com.openexchange.documentconverter.DocumentConverterManager;
+import com.openexchange.documentconverter.FileAndURL;
 import com.openexchange.documentconverter.FileIdManager;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
 import com.openexchange.documentconverter.MutableWrapper;
 import com.openexchange.documentconverter.NonNull;
+import com.openexchange.documentconverter.Nullable;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.documentconverter.client.impl.ClientConfig;
 import com.openexchange.documentconverter.client.impl.ClientManager;
+import com.openexchange.exception.OXException;
+import com.openexchange.file.storage.File;
 import com.openexchange.file.storage.FileStorageCapability;
 import com.openexchange.file.storage.FileStorageFileAccess;
+import com.openexchange.file.storage.FileStorageFolder;
 import com.openexchange.file.storage.composition.FolderID;
 import com.openexchange.file.storage.composition.IDBasedFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
+import com.openexchange.file.storage.composition.IDBasedFolderAccess;
+import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographicAwareIDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographyMode;
 import com.openexchange.groupware.attach.Attachments;
 import com.openexchange.java.Streams;
 import com.openexchange.mail.MailServletInterface;
 import com.openexchange.mail.compose.Attachment;
+import com.openexchange.mail.compose.AttachmentResult;
+import com.openexchange.mail.compose.CompositionSpaceId;
 import com.openexchange.mail.compose.CompositionSpaceService;
+import com.openexchange.mail.compose.CompositionSpaceServiceFactoryRegistry;
 import com.openexchange.mail.compose.CompositionSpaces;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.server.ServiceLookup;
@@ -120,6 +104,13 @@ public abstract class DocumentConverterAction implements AJAXActionService {
 
     final protected static String JSON_VALUE_DOUMENTCONVERTER = "DocumentConverter";
 
+    final protected static String FILE_SCHEMA = "file:///";
+
+    final protected static String MAIL_FOLDER = "Mail/";
+
+    final protected static String UNKNOWN_FILENAME = "unknown";
+
+
     /**
      * Initializes a new {@link DocumentConverterAction}.
      *
@@ -140,19 +131,19 @@ public abstract class DocumentConverterAction implements AJAXActionService {
      * @param jobError
      * @return
      */
-    protected File getRequestSourceFile(
+    public FileAndURL getRequestSourceFileAndURL(
         @NonNull final AJAXRequestData request,
         @NonNull final ServerSession session,
         @NonNull final MutableWrapper<Boolean> documentDecrypted,
         @NonNull final MutableWrapper<JobError> jobError) {
 
         final String documentId = getDocumentId(request);
-        File ret = null;
+        FileAndURL ret = null;
 
         try {
             m_fileIdManager.lock(documentId);
 
-            if (null == (ret = m_fileIdManager.getDataFile(documentId))) {
+            if (null == (ret = m_fileIdManager.getDataFileAndURL(documentId))) {
                 final String fileId = request.getParameter("id");
                 final String attachmentId = request.getParameter("attachmentId");
                 final String source = request.getParameter("source");
@@ -166,6 +157,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                 final boolean composeCheck = (fileId != null) && (attachmentId != null);
                 MailServletInterface mailServletInterface = null; // closing done in finally block
                 InputStream documentStm = null; // closing done in finally block
+                String documentURL = null;
 
                 try {
                     if (mailCheck && "mail".equals(source)) {
@@ -190,19 +182,29 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                             final MailPart mailPart = mailServletInterface.getMessageAttachment(folderId, fileId, attached, false);
 
                             if (null != mailPart) {
+                                final String fileName = mailPart.getFileName();
+
                                 documentStm = mailPart.getInputStream();
+                                documentURL = new StringBuilder(256).append(FILE_SCHEMA).append(MAIL_FOLDER).append(StringUtils.isNotBlank(fileName) ? fileName : UNKNOWN_FILENAME).toString();
                             }
                         }
                     } else if (composeCheck && "compose".equals(source)) {
                         // Composition space attachment
-                        CompositionSpaceService compositionSpaceService = m_services.getOptionalService(CompositionSpaceService.class);
-                        if (compositionSpaceService == null) {
+                        CompositionSpaceServiceFactoryRegistry registry = m_services.getOptionalService(CompositionSpaceServiceFactoryRegistry.class);
+                        if (registry == null) {
                             jobError.set(JobError.GENERAL);
                         } else {
-                            UUID compositionSpaceUuid = CompositionSpaces.parseCompositionSpaceId(fileId);
+                            CompositionSpaceId compositionSpaceId = new CompositionSpaceId(fileId);
                             UUID attachmentUuid = CompositionSpaces.parseAttachmentId(attachmentId);
-                            Attachment attachment = compositionSpaceService.getAttachment(compositionSpaceUuid, attachmentUuid, session);
-                            documentStm = attachment.getData();
+                            CompositionSpaceService compositionSpaceService = registry.getFactoryFor(compositionSpaceId.getServiceId(), session).createServiceFor(session);
+                            AttachmentResult attachmentResult = compositionSpaceService.getAttachment(compositionSpaceId.getId(), attachmentUuid);
+                            Attachment attachment = attachmentResult.getFirstAttachment();
+                            if (null != attachment) {
+                                documentStm = attachment.getData();
+                            } else {
+                                jobError.set(JobError.GENERAL);
+                                DocumentConverterManager.logError("DC client could not get attachment from CompositionSpaceService");
+                            }
                         }
                     } else if (taskCheck && ("tasks".equals(source) || "calendar".equals(source) || "contacts".equals(source))) {
                         // other attachment from tasks, calendar or contact
@@ -216,6 +218,8 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                             session.getContext(),
                             session.getUser(),
                             session.getUserConfiguration());
+
+                        documentURL = getFolderIdAndFileIdBasedFileUrl(session, folderId, fileId, null);
                     } else {
                         // use FileStore as default data source
                         final IDBasedFileAccessFactory fileFactory = m_services.getService(IDBasedFileAccessFactory.class);
@@ -263,11 +267,12 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                             }
 
                             documentStm = fileAccess.getDocument(fileId, versionToUse);
+                            documentURL = getFolderIdAndFileIdBasedFileUrl(session, folderId, fileId, versionToUse);
                         }
                     }
 
                     if (null != documentStm) {
-                        ret = m_fileIdManager.setDataInputStream(documentId, documentStm);
+                        ret = m_fileIdManager.setDataInputStreamAndURL(documentId, documentStm, documentURL);
                     }
                 } catch (final Exception e) {
                     DocumentConverterManager.logExcp(e);
@@ -299,7 +304,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
      * @param resultJobError
      * @return
      */
-    protected File getPDFFile(
+    protected FileAndURL getPDFFileAndURL(
         @NonNull final AJAXRequestData request,
         @NonNull final ServerSession session,
         final boolean isAsync,
@@ -308,7 +313,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
         @NonNull final MutableWrapper<JobError> resultJobError) {
 
         final IDocumentConverter docConverter = m_services.getService(IDocumentConverter.class);
-        File resultFile = null;
+        FileAndURL resultFileAndURL = null;
 
         resultJobError.set(JobError.GENERAL);
 
@@ -322,16 +327,16 @@ public abstract class DocumentConverterAction implements AJAXActionService {
             try {
                 m_fileIdManager.lock(resultJobId.get());
 
-                if (null == (resultFile = m_fileIdManager.getDataFile(resultJobId.get()))) {
-                    final File sourceFile = getRequestSourceFile(request, session, documentDecrypted, resultJobError);
+                if (null == (resultFileAndURL = m_fileIdManager.getDataFileAndURL(resultJobId.get()))) {
+                    final FileAndURL sourceFileAndURL = getRequestSourceFileAndURL(request, session, documentDecrypted, resultJobError);
 
-                    if(null != sourceFile) {
+                    if((null != sourceFileAndURL) && ((null != sourceFileAndURL.getFile()))) {
                         final String fileName = request.getParameter("filename");
 
                         if ((null != fileName) && "pdf".equalsIgnoreCase(FilenameUtils.getExtension(fileName))) {
                             // return source file in case of a PDF source
-                            try (final InputStream srcInputStm = FileUtils.openInputStream(sourceFile)) {
-                                resultFile = m_fileIdManager.setDataInputStream(resultJobId.get(), srcInputStm);
+                            try (final InputStream srcInputStm = FileUtils.openInputStream(sourceFileAndURL.getFile())) {
+                                resultFileAndURL = m_fileIdManager.setDataInputStreamAndURL(resultJobId.get(), srcInputStm, sourceFileAndURL.getURL());
                                 resultJobError.set(JobError.NONE);
                             }
                         } else {
@@ -346,10 +351,16 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                                 final HashMap<String, Object> jobProperties = new HashMap<>(12);
                                 final HashMap<String, Object> resultProperties = new HashMap<>(8);
 
-                                jobProperties.put(Properties.PROP_INPUT_FILE, sourceFile);
+                                jobProperties.put(Properties.PROP_INPUT_FILE, sourceFileAndURL.getFile());
                                 jobProperties.put(Properties.PROP_PRIORITY, JobPriority.fromString(request.getParameter("priority")));
                                 jobProperties.put(Properties.PROP_LOCALE, locale);
 
+                                final String inputURL = sourceFileAndURL.getURL();
+
+                                if (null != inputURL) {
+                                    jobProperties.put(Properties.PROP_INPUT_URL, inputURL);
+                                }
+
                                 if (null != fileName) {
                                     jobProperties.put(Properties.PROP_INFO_FILENAME, fileName);
                                 }
@@ -370,7 +381,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
 
                                 try (InputStream pdfResultStm = docConverter.convert("pdf", jobProperties, resultProperties)) {
                                     if (null != pdfResultStm) {
-                                        resultFile = m_fileIdManager.setDataInputStream(resultJobId.get(), pdfResultStm);
+                                        resultFileAndURL = m_fileIdManager.setDataInputStreamAndURL(resultJobId.get(), pdfResultStm, sourceFileAndURL.getURL());
                                         resultJobError.set(JobError.NONE);
                                     } else {
                                         JobError pdfJobError = JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
@@ -398,7 +409,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
             }
         }
 
-        return resultFile;
+        return resultFileAndURL;
     }
 
     /**
@@ -468,6 +479,53 @@ public abstract class DocumentConverterAction implements AJAXActionService {
         return documentIdBuilder.toString();
     }
 
+    /**
+     * @param session
+     * @param folderId
+     * @param fileId
+     * @param versionToUse providing <code>null</code> here uses the CURRENT_VERSION
+     * @return
+     */
+    protected String getFolderIdAndFileIdBasedFileUrl(@NonNull final ServerSession session, final String folderId, final String fileId, @Nullable final String versionToUse) {
+        final StringBuilder fileURLBuilder = new StringBuilder(512);
+
+        if ((null != folderId) && (null != fileId)) {
+            try {
+                final IDBasedFileAccessFactory fileFactory = m_services.getService(IDBasedFileAccessFactory.class);
+                IDBasedFileAccess fileAccess = (null != fileFactory) ? fileFactory.createAccess(session) : null;
+                final File fileMetadata = (null != fileAccess) ? fileAccess.getFileMetadata(fileId, versionToUse) : null;
+
+                if (null != fileMetadata) {
+                    final IDBasedFolderAccessFactory folderFactory = m_services.getService(IDBasedFolderAccessFactory.class);
+
+                    fileURLBuilder.append(FILE_SCHEMA);
+
+                    // append all folders to URL
+                    if (null != folderFactory) {
+                        IDBasedFolderAccess folderAccess = folderFactory.createAccess(session);
+
+                        if (null != folderAccess) {
+                            FileStorageFolder[] fileStorageFolders = folderAccess.getPath2DefaultFolder(folderId);
+
+                            if (null != fileStorageFolders) {
+                                for (int i = fileStorageFolders.length - 1; i >= 0; --i) {
+                                    fileURLBuilder.append(fileStorageFolders[i].getName()).append('/');
+                                }
+                            }
+                        }
+                    }
+
+                    // append filename to URL
+                    fileURLBuilder.append(fileMetadata.getFileName());
+                }
+            } catch (OXException e) {
+                DocumentConverterManager.logExcp(e);
+            }
+        }
+
+        return fileURLBuilder.toString();
+    }
+
     // - Members ---------------------------------------------------------------
 
     final protected ServiceLookup m_services;
