@@ -1,52 +1,27 @@
-/* *
- *    OPEN-XCHANGE legal information
+/*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    All intellctual property rights in the Software are protected by
- *    international copyright laws.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 
+
+
 package com.openexchange.documentconverter.client.json;
 
 import java.io.File;
@@ -64,6 +39,7 @@ import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.documentconverter.DocumentConverterManager;
+import com.openexchange.documentconverter.FileAndURL;
 import com.openexchange.documentconverter.FileIdManager;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
@@ -121,7 +97,7 @@ public class GetDocumentAction extends DocumentConverterAction {
         final MutableWrapper<Boolean> documentDecrypted = new MutableWrapper<>(Boolean.FALSE);
         final MutableWrapper<String> jobId = new MutableWrapper<>(null);
         final MutableWrapper<JobError> jobError = new MutableWrapper<>(JobError.NONE);
-        File resultFile = null;
+        FileAndURL resultFileAndURL = null;
 
         // don't convert to PDF, if it is requested ("documentformat==pdf") but the source file is a PDF file
         // already, determined by either the file extension ("pdf") or the mime type ("application/pdf")
@@ -129,27 +105,36 @@ public class GetDocumentAction extends DocumentConverterAction {
             "pdf".equalsIgnoreCase(request.getParameter("documentformat")) &&
             !"pdf".equals(fileExtension) && !"application/pdf".equalsIgnoreCase(mimeType);
 
-        if ((!convertToPDF || ((null == (resultFile = getPDFFile(request, session, isAsync, documentDecrypted, jobId, jobError))) && (JobError.NONE == jobError.get()))) && !isAsync) {
+        if ((!convertToPDF ||
+            ((null == (resultFileAndURL = getPDFFileAndURL(request, session, isAsync, documentDecrypted, jobId, jobError))) &&
+             (JobError.NONE == jobError.get()))) &&
+            !isAsync) {
+
             final IDocumentConverter docConverter = m_services.getService(IDocumentConverter.class);
             final String encTest = request.getParameter("enctest");
 
             // In case of PDF input and output, the result file is equal to the source file
-            resultFile = getRequestSourceFile(request, session, documentDecrypted, jobError);
+            resultFileAndURL = getRequestSourceFileAndURL(request, session, documentDecrypted, jobError);
 
             // If source/result file is a PDF file and encTest is set to 'pdf', do an
             // encryption test to get a valid error code in case of an encrypted PDF
             if (!convertToPDF &&
-                (null != resultFile) &&
+                (null != resultFileAndURL) &&
                 (null != encTest) && encTest.equalsIgnoreCase("pdf") &&
                 (null != docConverter)) {
 
                 final HashMap<String, Object> jobProperties = new HashMap<>(12);
                 final HashMap<String, Object> resultProperties = new HashMap<>(8);
 
-                jobProperties.put(Properties.PROP_INPUT_FILE, resultFile);
+                jobProperties.put(Properties.PROP_INPUT_FILE, resultFileAndURL.getFile());
                 jobProperties.put(Properties.PROP_PRIORITY, JobPriority.fromString(request.getParameter("priority")));
                 jobProperties.put(Properties.PROP_LOCALE, getPreferredLanguage(session));
 
+                final String inputURL = resultFileAndURL.getURL();
+
+                if (null != inputURL) {
+                    jobProperties.put(Properties.PROP_INPUT_URL, inputURL);
+                }
 
                 if (null != fileName) {
                     jobProperties.put(Properties.PROP_INFO_FILENAME, fileName);
@@ -176,7 +161,8 @@ public class GetDocumentAction extends DocumentConverterAction {
 
             if (isAsync) {
                 (jsonResult = new JSONObject()).put("async", true);
-            } else if (null != resultFile) {
+            } else if (null != resultFileAndURL) {
+                final File resultFile = resultFileAndURL.getFile();
                 final String sessionId = request.getParameter("session");
                 final String saveAsFileName = request.getParameter("saveas_filename");
                 final String saveAsFolderId = request.getParameter("saveas_folder_id");
