@@ -1,51 +1,26 @@
-/* *
- *    OPEN-XCHANGE legal information
+/*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    All intellctual property rights in the Software are protected by
- *    international copyright laws.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
+
+
 package com.openexchange.documentconverter.client.preview;
 
 import java.io.BufferedInputStream;
@@ -329,6 +304,12 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
             jobProperties.put(Properties.PROP_HIDE_COMMENTS, Boolean.TRUE);
         }
 
+        /* TODO (KA): set InputUrl property, if known later
+        if (null != inputURL) {
+            jobProperties.put(Properties.PROP_INPUT_URL, inputURL);
+        }
+        */
+
         // just log the filename of the request in error case
         if (null != fileName) {
             jobProperties.put(Properties.PROP_INFO_FILENAME, fileName);
@@ -450,7 +431,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                 } catch (Exception e) {
                     handleExcp(e);
                 } finally {
-                    IOUtils.closeQuietly(resultInputStm);
+                    DocumentConverterManager.close(resultInputStm);
                     resultInputStm = null;
                 }
 
@@ -497,7 +478,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
             } catch (Exception e) {
                 handleExcp(e);
             } finally {
-                IOUtils.closeQuietly(resultInputStm);
+                DocumentConverterManager.close(resultInputStm);
                 resultInputStm = null;
             }
 
@@ -539,8 +520,8 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
             // ok, this may happen with some formats as a try,
             // but shouldn't give any output in the log file
         } finally {
-            IOUtils.closeQuietly(zipInputStm);
-            IOUtils.closeQuietly(inputStm);
+            DocumentConverterManager.close(zipInputStm);
+            DocumentConverterManager.close(inputStm);
         }
 
         return resultBuffer;
@@ -577,7 +558,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
             } catch (IOException e) {
                 handleExcp(e);
             } finally {
-                IOUtils.closeQuietly(resourceInputStream);
+                DocumentConverterManager.close(resourceInputStream);
             }
         }
 
